@@ -9,12 +9,12 @@
 ** modify it under the terms of the GNU Lesser General Public
 ** License as published by the Free Software Foundation; either
 ** version 2.1 of the License, or (at your option) any later version.
-** 
+**
 ** This library is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ** Lesser General Public License for more details.
-** 
+**
 ** You should have received a copy of the GNU Lesser General Public
 ** License along with this library; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -40,10 +40,10 @@
 
 START_LIBMATROSKA_NAMESPACE
 
-#define LIBMATROSKA_VERSION 0x000900
+#define LIBMATROSKA_VERSION 0x010300
 
-static const std::string KaxCodeVersion = "0.9.0";
-static const std::string KaxCodeDate    = __TIMESTAMP__;
+extern const std::string KaxCodeVersion;
+extern const std::string KaxCodeDate;
 
 /*!
 	\todo Improve the CRC/ECC system (backward and forward possible ?) to fit streaming/live writing/simple reading
